@@ -284,6 +284,13 @@ unsigned int suhosin_input_filter_wrapper(int arg, char *var, char **val, unsign
 	zend_bool already_scanned = SUHOSIN_G(already_scanned);
 	SUHOSIN_G(already_scanned) = 0;
 	
+	if (SUHOSIN_G(do_not_scan)) {
+		if (new_val_len) {
+			*new_val_len = val_len;
+		}
+                return 1;
+	}
+	
 	if (!already_scanned) {
 		if (suhosin_input_filter(arg, var, val, val_len, new_val_len TSRMLS_CC)==0) {
 			SUHOSIN_G(abort_request)=1;
