@@ -630,7 +630,19 @@ void suhosin_hook_session(TSRMLS_D)
 	if (zend_hash_find(&module_registry, "session", sizeof("session"), (void**)&module) == FAILURE) {
 		return;
 	}
-	/* retrieve globals */
+    /* retrieve globals from module entry struct if possible */
+#if PHP_VERSION_ID >= 50200
+#ifdef ZTS
+    if (session_globals_id == 0) {
+        session_globals_id = *module->globals_id_ptr;
+    }
+#else
+    if (session_globals == NULL) {
+        session_globals = module->globals_ptr;
+    }
+#endif
+#else
+	/* retrieve globals from symbols if PHP version is old */
 #ifdef ZTS
 	if (session_globals_id == 0) {
 		ps_globals_id_ptr = DL_FETCH_SYMBOL(module->handle, "ps_globals_id");
@@ -653,6 +665,7 @@ void suhosin_hook_session(TSRMLS_D)
 			return;
 		}
 	}
+#endif
 #endif
 	if (old_OnUpdateSaveHandler != NULL) {
 		return;
